@@ -6,7 +6,7 @@ use Carp;
 use LWP::UserAgent;
 use HTML::Tiny;
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 use constant API_SERVER => 'http://www.google.com/recaptcha/api';
 use constant API_SECURE_SERVER =>
@@ -117,6 +117,7 @@ sub _post_request {
   my ( $url, $args ) = @_;
 
   my $ua = LWP::UserAgent->new();
+  $ua->env_proxy();
   return $ua->post( $url, $args );
 }
 
@@ -330,6 +331,12 @@ and C<error>.
 
 See the /examples subdirectory for examples of how to call C<check_answer>.
 
+Note: this method will make an HTTP request to Google to verify the user input.
+If this request must be routed via a proxy in your environment, use the
+standard environment variable to specify the proxy address, e.g.:
+
+    $ENV{http_proxy} = 'http://myproxy:3128';
+
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
